# junit.html

Report generated on 28-Mar-2024 at 16:28:50 by pytest-html v4.1.1

## Environment

## Summary

39 tests took 00:00:06.

(Un)check the boxes to filter the results.

There are still tests running.
Reload this page to get the latest results!
0 Failed, 39 Passed, 0 Skipped, 0 Expected failures, 0 Unexpected passes, 0 Errors, 0 Reruns
/

Result | Test | Duration | Links
--- | --- | --- | ---